@@ -9,9 +9,9 @@ if [ "$(echo "intel123" | sudo docker ps -q -f name=^collectd$)" ]; then
 else
     echo "Installing System-Telemetry service"
     export HOST_IP=$(hostname -I | cut -d' ' -f1)
-    python_path=$(python3 -m site --user-site)
+    ver=$(python3 --version | grep Python | awk '{print $2}' | xargs printf '%0.1f\n')
     if [ $1=="all-services" ]; then      
-        sudo -E docker-compose -f $python_path/src/scripts/app-services/system-telemetry/docker-compose-app-service.yaml  up -d --build influxdb grafana collectd    
+        sudo -E docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/system-telemetry/docker-compose-app-service.yaml  up -d --build influxdb grafana collectd    
     fi
 fi
 
